Zillion is written and maintained by totalhack. Contributors welcome!

# **Core Contributors**

- [@totalhack](https://github.com/totalhack)

# **Patches and Suggestions**

Please see the [contributing](https://github.com/totalhack/zillion/blob/master/CONTRIBUTING.md)
guide for more information.
